### Trajectory XGBoost Classifier

\[ *Runnable is included in Library* \]

You can run the classifier with the following command:
```bash
MAT-TC.py -ds "<DATASET_PREFIX>" -c "TXGB" "${DATAPATH}/${RUN}" "${DIR}"
```

Example:
```bash
MAT-TC.py -ds "specific" -c "TXGB" "Datasets/Foursquare/run1" "TXGB-experiment01"
```


##### Reference:

| Title | Authors | Year | Venue | Links | Cite |
|:------|:--------|------|:------|:------|:----:|
| Xgboost: A scalable tree boosting system | Chen, T. and Guestrin, C. | 2016 | In Proceedings of the ACM SIGKDD International Conference on Knowledge Discovery and Data Mining, volume 13 |  |  |
| Using Deep Learning for Trajectory Classification | Nicksson A. de Freitas.; Ticiana Coelho da Silva.; José Fernandes de Macêdo.; Leopoldo Melo Junior.; Matheus Cordeiro | 2021 | In Proceedings of the 13th International Conference on Agents and Artificial Intelligence - Volume 2: ICAART | [Article](http://dx.doi.org/10.5220/0010227906640671) [Repository](https://github.com/nickssonfreitas/ICAART2021) |  |